<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['%d association'] = 'סך הכול %d';
$lang['%d associations'] = 'סך הכול %d';
$lang['%d album including'] = 'כולל הקטגוריה %d';
$lang['%d albums including'] = 'כולל הקטגוריות %d';
$lang['%d physical'] = 'פיזי %d';
$lang['%d physical'] = 'פיזי %d';
$lang[' and %d virtual'] = 'ו %d וירטואלי';
$lang[' and %d virtual'] = 'ו %d וירטואלים';
$lang['%d album moved'] = '%d קטגוריה עברה';
$lang['%d albums moved'] = '%d קטגוריות עברו';
$lang['%d group'] = '%d קבוצה';
$lang['%d groups'] = '%d קבוצות';
$lang['%d member'] = '%d חבר';
$lang['%d members'] = '%d חברים';
$lang['%d tag'] = '%d תג';
$lang['%d tags'] = '%d תגיות';
$lang['%d user comment rejected'] = '%d תגובת המשתמש נדחתה';
$lang['%d user comments rejected'] = '%d תגובות המשתמש נדחו';
$lang['%d user comment validated'] = '%d תגובת המשתמש אושרה';
$lang['%d user comments validated'] = '%d תגובות המשתמש אושרו';
$lang['%d user deleted'] = '%d המשתמש נמחק';
$lang['%d users deleted'] = '%d המשתמשים נמחקו';
$lang['%d user'] = '%d משתמש';
$lang['%d users'] = '%d משתמשים';
$lang['%d waiting for validation'] = '%d מחכה לאימות';
$lang['Actions'] = 'פעולות';
$lang['Activate'] = 'להפעיל';
$lang['Add/delete a permalink'] = 'הוספה / מחיקה של קישורית';
$lang['Add a tag'] = 'הוסף תגית';
$lang['Add a user'] = 'הוסף משתמש';
$lang['Add group'] = 'הוסף קבוצה';
$lang['Add'] = 'הוסף';
$lang['Allow user registration'] = 'אפשר רישום משתמשים';
$lang['Apply to sub-albums'] = 'החל על קטגוריות משניות';
$lang['Associated'] = 'שייך';
$lang['Batch management'] = 'ניהול קבוצה';
$lang['Caddie management'] = 'ניהול סל';
$lang['Caddie'] = 'סל';
$lang['Albums authorized thanks to group associations'] = 'הקטגוריה מאושרת אודות לקבוצת האסוציאציות';
$lang['Album manual order was saved'] = 'סדר הקטגוריות נשמר';
$lang['Check for upgrade failed for unknown reasons.'] = 'בדוק אם השדרוג נכשל מסיבות לא ידועות.';
$lang['Check for upgrade'] = 'חפש עדכונים שדרוגים';
$lang['Comments for all'] = 'תגובות עבור כל';
$lang['Current name'] = 'השם הנוכחי';
$lang['Database'] = 'מסד נתונים';
$lang['Deactivate'] = 'לא פעיל';
$lang['Delete Representant'] = 'מחק הצגה';
$lang['Delete selected tags'] = 'מחק את התגים שנבחרו';
$lang['Delete selected users'] = 'מחק את המשתמשים שנבחרו';
$lang['Deletions'] = 'מחיקות';
$lang['Deny selected groups'] = 'אסור קבוצות שנבחרו';
$lang['Deny selected users'] = 'אסור משתמשים שנבחרו';
$lang['Description'] = 'תיאור';
$lang['Display options'] = 'הצגת אפשרויות';
$lang['Dissociated'] = 'מנותק';
$lang['Does not represent'] = 'האם לא מייצג';
$lang['Edit selected tags'] = 'ערוך את התגים הנבחרים';
$lang['Edit tags'] = 'ערוך תגיות';
$lang['Email admins when a new user registers'] = 'שלח מייל למנהל כאשר נרשם משתמש חדש';
$lang['Email admins when a valid comment is entered'] = 'שלח מייל למנהל כאשר נרשמת תגובה';
$lang['Email admins when a comment requires validation'] = 'שלח מייל למנהל כאשר נדרש אימות לתגובה';
$lang['Environment'] = 'סביבה';
$lang['Form'] = 'טופס';
$lang['Gallery title'] = 'כותרת הגלריה';
$lang['Grant selected groups'] = 'להעניק לקבוצות שנבחרו';
$lang['Grant selected users'] = 'להענית למשתמשים שנבחרו';
$lang['Group name'] = 'שם הקבוצה';
$lang['Groups'] = 'קבוצות';
$lang['Guests'] = 'האורחים';
$lang['History'] = 'היסטוריה';
$lang['Informations'] = 'מידע';
$lang['Install'] = 'התקן';
$lang['Link all album photos to a new album'] = 'קישור כל הפריטים בקטגוריה לקטגוריה חדשה';
$lang['Link all album photos to some existing albums'] = 'קישור כל הפריטים בקטגוריה לקטגוריה קיימת';
$lang['Linked albums'] = 'קטגוריות מקושרות';
$lang['Lock gallery'] = 'גלריה נעולה';
$lang['Maintenance'] = 'תחזוקה';
$lang['Edit album permissions'] = 'ניהול הרשאות עבור קטגוריה';
$lang['Manage permissions for group "%s"'] = 'ניהול הרשאות עבור קבוצה "%s"';
$lang['Manage permissions for user "%s"'] = 'ניהול הרשאות עבור המשתמש "%s"';
$lang['Manage tags'] = 'ניהול תגים';
$lang['Members'] = 'חברים';
$lang['Metadata synchronized from file'] = 'סנכרון מידע מקובץ';
$lang['Move albums'] = 'העבר הקטגוריות';
$lang['Move'] = 'העבר';
$lang['Name'] = 'שם';
$lang['New name'] = 'שם חדש';
$lang['New parent album'] = 'קטגורית אם חדשה';
$lang['New tag'] = 'תג חדש';
$lang['Number of comments per page'] = 'מספר תגובות בעמוד';
$lang['Number of rates'] = 'מספר שיעורי';
$lang['Number of thumbnails to create'] = ' מספר של תמונות ממוזערות ליצור';
$lang['Only private albums are listed'] = 'קטגוריה פרטים לרשומים בלבד';
$lang['Operating system'] = 'מערכת הפעלה';
$lang['Options'] = 'אפשרויות';
$lang['Other private albums'] = 'קטגוריות פרטיות אחרות';
$lang['Page banner'] = 'באנר הדף';
$lang['Parent album'] = 'קטגורית אם';
$lang['Path'] = 'נתיב';
$lang['Permalink'] = 'קישורית'; 
$lang['Permalink %s has been previously used by album %s. Delete from the permalink history first'] = 'השתמשו בעבר ב Permalink "%s" "זה עבור הקטגוריה "%s". מחק אותו ההסטוריה של permalink';
$lang['The permalink name must be composed of a-z, A-Z, 0-9, "-", "_" or "/". It must not be numeric or start with number followed by "-"'] = 'השם Permalink חייב להיות מורכב a-z, A-Z, 0-9, "-", "_" או "/".הוא חייב לא להיות מספרי או להתחיל עם מספר "-"';
$lang['Permalink %s is already used by album %s'] = 'Permalink "%s" "נמצא כבר בשימוש על ידי הקטגוריה "%s"';
$lang['Permalink history'] = 'ההיסטוריה Permalinks';
$lang['Permalinks'] = 'קישורים מפנים';
$lang['Permission denied'] = 'ההרשאה נדחתה';
$lang['Permission granted thanks to a group'] = 'ההרשאה ניתנה בזכות הקבוצה';
$lang['Permission granted'] = 'ניתנה הרשאה';
$lang['Photo informations updated'] = 'מידע עבור התמונות הועלה';
$lang['Plugins'] = 'תוספים';
$lang['Position'] = 'מיקום';
$lang['Preferences'] = 'העדפות';
$lang['Properties'] = 'נכסים';
$lang['Random photo'] = 'תמונה אקראית';
$lang['Rate date'] = 'תאריך דירוג';
$lang['Rating by guests'] = 'דירוג על ידי אורחים';
$lang['Rating'] = 'דירוג';
$lang['Reject'] = 'דחה';
$lang['Representant'] = 'נציג';
$lang['Representation of albums'] = 'ייצוג קטגוריות';
$lang['Representative'] = 'הנציג';
$lang['Represents'] = 'מייצג';
$lang['Save order'] = 'שמור סדר';
$lang['Save to permalink history'] = 'שמור להיסטורית Permalinks';
$lang['Select at least one album'] = 'בחר לפחות בקטגוריה אחת';
$lang['Select at least one photo'] = 'בחר לפחות תמונה אחת';
$lang['Select at least one user'] = 'בחר לפחות משתמש אחד';
$lang['Show info'] = 'הצג מידע';
$lang['Site manager'] = 'מנהל אתר';
$lang['Status'] = 'סטטוס';
$lang['Statistics'] = 'סטטיסטיקה';
$lang['Storage album'] = 'מחסן קטגוריות';
$lang['Sum of rates'] = 'סכום של דירוג';
$lang['Tag "%s" already exists'] = 'התג "%s"" כבר קיים';
$lang['Tag "%s" was added'] = 'התג "%s"" נוסף';
$lang['Tag selection'] = 'בחירת תגית';
$lang['The %d following tags were deleted'] = 'התגיות הבאות %d נמחקו';
$lang['Unable to check for upgrade.'] = 'אין אפשרות לבדוק אם קיימים שדרוגים.';
$lang['Uninstall'] = 'הסר';
$lang['Use the default photo sort order (defined in the configuration file)'] = 'השתמש תמונת ברירת המחדל להרשמה קצרה (מוגדרים בקובץ התצורה)';
$lang['User comments validation'] = 'תגובות מאושרות של המשתמש';
$lang['Users'] = 'משתמשים';
$lang['Validate'] = 'אמת';
$lang['Validation'] = 'אימות';
$lang['Version'] = 'גרסה';
$lang['Virtual albums to move'] = 'הקטגוריות וירטואליות להעברה';
$lang['Virtual album name'] = 'שם קטגוריה וירטואלית';
$lang['Webmaster cannot be deleted'] = 'לא ניתן למחוק את מנהל האתר';
$lang['You are running on development sources, no check possible.'] = 'אתה פועל על מקורות בפיתוח, לא ניתן לבדוק.';
$lang['You cannot delete your account'] = 'אתה לא יכול למחוק את החשבון שלך';
$lang['You cannot move an album in its own sub album'] = 'אתה לא יכול להעביר קטגוריה לתוך התת קטגוריה שלה';
$lang['You need to confirm deletion'] = 'אתה חייב לאשר את המחיקה';
$lang['add tags'] = 'להוסיף תגיות';
$lang['Associate to album'] = 'לשייך לקטגוריה';
$lang['associate to group'] = 'לשייך לקבוצה';
$lang['Authorized'] = 'מורשה';
$lang['Add a virtual album'] = 'הוספת קטגוריה וירטואלית';
$lang['Authorize users to add comments on selected albums'] = 'הרשה למשתמשים להוסיף תגובות לקטגוריות שנבחרו';
$lang['The name of an album must not be empty'] = 'השם של הקטגוריה לא יכול להיות ריק';
$lang['Lock albums'] = 'נעל קטגוריות';
$lang['Private'] = 'קטגוריה פרטית';
$lang['Public'] = 'קטגוריה ציבורית';
$lang['Find a new representant by random'] = 'מצא ייצוג אקראי חדש';
$lang['Public / Private'] = 'ציבורי / פרטי';
$lang['Manage authorizations for selected albums'] = 'נהל הרשאות עבור הקטגוריות שנבחרו';
$lang['Virtual album added'] = 'קטגוריה וירטואלית נוספה';
$lang['Virtual album deleted'] = 'קטגוריה וירטואלית נמחקה';
$lang['Access type'] = 'סוג גישה';
$lang['Comments'] = 'תגובות';
$lang['Information data registered in database'] = 'מידע הנתונים רשום במאגר נתונים';
$lang['Default display'] = 'תצוגת ברירת המחדל';
$lang['The gallery URL is not valid.'] = 'ה-URL בגלריה אינו חוקי.';
$lang['Main'] = 'ראשי';
$lang['The number of comments a page must be between 5 and 50 included.'] = 'מספר הערות בדף חייב להיות בין 5 ל 50 כולל.';
$lang['Configuration'] = 'תצורה';
$lang['confirm'] = 'לאשר';
$lang['Date'] = 'תאריך';
$lang['delete album'] = 'למחוק את הקטגוריה';
$lang['Dissociate from album'] = 'נתק מהקטגוריה';
$lang['dissociate from group'] = 'נתק מהקבוצה';
$lang['edit album permissions'] = 'ערוך הרשאות לקטגוריה';
$lang['Album updated successfully'] = 'מידע על הקטגוריה עודכן בהצלחה.';
$lang['photos per page'] = 'פריטים בעמוד';
$lang['High definition enabled'] = 'איכות גבוהה מופעלת';
$lang['File'] = 'קובץ';
$lang['Filesize'] = 'גודל הקובץ';
$lang['first photo added on %s'] = 'הפריט הראשון התווסף ב"%s "';
$lang['Forbidden'] = 'אסורה';
$lang['global mode'] = 'מצב גלובלי';
$lang['group "%s" added'] = 'הקבוצה "%s"" נוספה';
$lang['group "%s" deleted'] = 'הקבוצה "%s"" נמחקה';
$lang['group "%s" updated'] = 'הקבוצה "%s"" הועלתה';
$lang['group'] = 'קבוצה';
$lang['The name of a group must not contain " or \' or be empty.'] = "שם של קבוצה לא יכול להכיל מרחאות או ' או להיות ריק";
$lang['This name is already used by another group.'] = 'שם זה נמצא כבר בשימוש על ידי קבוצה אחרת.'; 

$lang['High definition'] = 'בחדות גבוהה';
$lang['jump to album'] = 'לקפוץ לקטגוריה';
$lang['jump to photo'] = 'קפיצה אל התמונה';
$lang['leave'] = 'לעזוב';
$lang['Lock'] = 'נעל';
$lang['Locked'] = 'נעול';
$lang['manage album photos'] = 'ניהול פריטים בקטגוריה';
$lang['manage sub-albums'] = 'ניהול קטגוריות משנה';
$lang['Manage'] = 'ניהול';
$lang['maximum height'] = 'גובה מרבי';
$lang['maximum width'] = 'רוחב מרבי';
$lang['Execution time is out, treatment must be continue [Estimated time: %d second].'] = 'זמן ביצוע יוצא, הטיפול חייב להיות המשך [זמן משוער:% השני ד].';
$lang['Execution time is out, treatment must be continue [Estimated time: %d seconds].'] = 'זמן ביצוע חריגה, הטיפול חייב להמשיך [זמן משוער:% d שניות].';
$lang['Prepared time for list of users to send mail is limited. Others users are not listed.'] = 'הגיע הזמן להכין את רשימת המשתמשים אשר יישלח בדואר מוגבל למשתמשים אחרים אינם מפורטים..';
$lang['Time to send mail is limited. Others mails are skipped.'] = 'הזמן כדי לשלוח דואר אלקטרוני מוגבל אחרים כבר דילג..';
$lang['To send ?'] = 'כדי לשלוח?';
$lang['Last send'] = 'לאחרונה שלחה';
$lang['email'] = 'דואר אלקטרוני';
$lang['User'] = 'משתמש';
$lang['Complementary mail content'] = 'דואר תוכן משלימים';
$lang['See you soon,'] = 'נתראה בקרוב';
$lang['Go to'] = 'עבור';
$lang['Hello'] = 'שלום';
$lang['New photos were added'] = 'אלמנטים חדשים נוספו';
$lang['on'] = 'על  Piwigo';
$lang['between'] = 'בין';
$lang['and'] = 'ו';
$lang['The webmaster has subscribed you to receiving notifications by mail.'] = 'שמנהל האתר רשום לך לקבל הודעות בדואר.';
$lang['You have subscribed to receiving notifications by mail.'] = 'יש לך מנוי כדי לקבל הודעות בדואר.';
$lang['To subscribe'] = 'כדי להירשם';
$lang['If you encounter problems or have any question, please send a message to'] = 'אם אתה נתקל בבעיות או יש לך שאלה, שילחו הודעה ל';
$lang['[NBM] Problems or questions'] = '[NBM] בעיות או שאלות';
$lang['The webmaster has unsubscribed you from receiving notifications by mail.'] = 'שמנהל האתר הרשמתך ממך לקבל הודעות בדואר.';
$lang['You have unsubscribed from receiving notifications by mail.'] = 'ביטלת את המנוי מלהיות הודעה בדואר.';
$lang[', click on'] = ', לחץ על';
$lang['To unsubscribe'] = 'כדי לבטל את המינוי';
$lang['With blank value, gallery title will be used'] = 'אם ריק, הכותרת בגלריה ישמש';
$lang['Notification'] = 'עידכוני RSS';
$lang['Error when sending email to %s [%s].'] = 'שגיאה בעת שליחת דוא"ל אל""%s" "["%s"].';
$lang['Mail sent to %s [%s].'] = 'דואר שנשלח""%s" "["%s"].';
$lang['%d mail was sent.'] = 'ד הדואר% נשלחה.';
$lang['%d mails were sent.'] = 'ד אלקטרוני% נשלחו.';
$lang['%d mail was not sent.'] = 'ד הדואר% לא נשלחה.';
$lang['%d mails were not sent.'] = 'ד אלקטרוני% לא נשלחו.';
$lang['No mail to send.'] = 'דואר לא יישלחו.';
$lang['There is no available subscribers to mail.'] = 'אין נרשמים כדי לקבל הודעה בדואר.';
$lang['Subscribers could be listed (available) only if there is new elements to notify.'] = 'המנויים יכולים להיות רשומים (כניסה) רק אם יש אלמנטים חדשים כדי להודיע.';
$lang['Anyway only webmasters can see this tab and never administrators.'] = 'מנהלי אתרים רק בכל אופן ניתן לראות את הכרטיסייה, לא מנהלים.';
$lang['No user to send notifications by mail.'] = 'המשתמש לא כדי לקבל הודעה בדואר.';
$lang['New photos added'] = 'אלמנטים חדשים שנוספו';
$lang['Subscribe to notification by mail'] = 'מודלים הודעה בדואר';
$lang['Unsubscribe from notification by mail'] = 'הסרה מרשימת הודעה בדואר';
$lang['Parameter'] = 'הגדרות';
$lang['Operation in progress'] = 'הטיפול מתבצעת.';
$lang['Continue processing treatment'] = 'המשך הטיפול השוטף';
$lang['Complementary mail content'] = 'דואר תוכן משלימים';
$lang['Add detailed content'] = 'מוסיפים קצת תוכן מפורט';
$lang['Send mail as'] = 'שלח דואר כ';
$lang['Send mail to users'] = 'שלח דואר למשתמשים';
$lang['Send'] = 'שלח';
$lang['Options'] = 'אפשרויות';
$lang['Subscribed'] = 'מנויים';
$lang['Subscribe'] = 'הרשם';
$lang['Parameters'] = 'פרמטרים';
$lang['Select recipients'] = 'בחירת נמענים';
$lang['Subscribe/unsubscribe users'] = 'להירשם / לבטל את המנוי משתמשים';
$lang['Unsubscribed'] = 'המינוי';
$lang['%d parameter was updated.'] = 'ד פרמטר% המעודכן.';
$lang['%d parameters were updated.'] = 'ד הפרמטרים% המעודכן.';
$lang['%d user was not updated.'] = 'המשתמש% d לא מעודכן.';
$lang['%d users were not updated.'] = 'ד למשתמשים% לא מעודכן.';
$lang['User %s [%s] was removed from the subscription list.'] = 'המשתמש""%s" "["%s"] מרשימת המנויים.';
$lang['User %s [%s] was added to the subscription list.'] = 'המשתמש""%s" "["%s"] לרשימת המנויים.';
$lang['%d user was updated.'] = 'ד המשתמש% המעודכן.';
$lang['%d users were updated.'] = 'ד למשתמשים% המעודכן.';
$lang['User %s [%s] was not removed from the subscription list.'] = 'המשתמש""%s" "["%s"] לא יוסר מרשימת המנויים.';
$lang['User %s [%s] was not added to the subscription list.'] = 'המשתמש""%s" "["%s"] לא הוסיף לרשימה המנוי.';
$lang['User %s [%s] added.'] = 'המשתמש""%s" "["%s"] הוסיף.';
$lang['Warning: subscribing or unsubscribing will send mails to users'] = 'אזהרה: מנוי או ביטול המנוי תשלח מיילים למשתמשים';
$lang['Send mail on HTML format'] = 'שלח דואר בתבנית HTML';
$lang['Include display of recent photos grouped by dates'] = 'להציג כלול התמונות האחרונות מקובצים לפי תאריכים';
$lang['Available only with HTML format'] = 'ניתן להשיג רק עם פורמט HTML';
$lang['no write access'] = 'אין גישה לכתוב';
$lang['Permissions'] = 'הרשאות';
$lang['private'] = 'פרטית';
$lang['public'] = 'הציבור';
$lang['Purge never used notification feeds'] = 'הטיהור מעולם ההודעה בשימוש הזנות';
$lang['Purge sessions'] = 'מפגשים הטיהור';
$lang['randomly represented'] = 'נציג אקראי';
$lang['registration date'] = 'תאריך רישום';
$lang['clean'] = 'לנקות';
$lang['remove remote listing.xml file'] = 'להסיר את הקובץ listing.xml מרחוק';
$lang['generate listing'] = 'לייצר רשימה';
$lang['generate file listing.xml on remote site'] = 'לייצר listing.xml הקובץ באתר מרוחק';
$lang['Create this site'] = 'צור את האתר הזה';
$lang['A local listing.xml file has been found for'] = 'הקובץ listing.xml המקומית כבר מצאו עבור';
$lang['read local listing.xml and update'] = 'לקרוא listing.xml עדכון המקומית';
$lang['test'] = 'מבחן';
$lang['test this remote site'] = 'מבחן זה באתר מרוחק'; 
$lang['remove tags'] = 'להסיר את תגי';
$lang['Repair and optimize database'] = 'תיקון מסד אופטימיזציה';
$lang['selection'] = 'הבחירה';
$lang['set to'] = 'מוגדר';
$lang['singly represented'] = 'נציג קבוע';
$lang['This site already exists'] = 'אתר זה כבר קיים';
$lang['Create a new site : (give its URL to create_listing_file.php)'] = 'צור אתר חדש: (לתת את כתובת האתר שלו כדי create_listing_file.php)';
$lang['created'] = 'יצר';
$lang['delete'] = 'למחוק';
$lang['delete this site and all its attached elements'] = 'למחוק את האתר הזה ואת כל המידע בנושא';
$lang['an error happened'] = 'אירעה שגיאה';
$lang['file create_listing_file.php on remote site was not found'] = 'Create_listing_file.php הקובץ לא נמצא באתר המרוחק';
$lang['Local'] = 'מקומית';
$lang['Remote'] = 'מרחוק';
$lang['synchronize'] = 'לסנכרן';
$lang['update the database from files'] = 'לעדכן את מסד הנתונים עם קבצים';
$lang['status'] = 'מעמד';
$lang['Directory'] = 'מדריך';
$lang['sub-albums'] = 'קטגוריות משנה';
$lang['synchronize metadata'] = 'לסנכרן מטה';
$lang['target'] = 'המטרה';
$lang['Thumbnail'] = 'תמונה';
$lang['title'] = 'כותרת';
$lang['Album list management'] = 'ניהול קטגוריות';
$lang['Piwigo configuration'] = 'תצורה Piwigo';
$lang['Edit album'] = 'ערוך קטגוריה';
$lang['Group management'] = 'ניהול קבוצות';
$lang['User list'] = 'רשימת משתמשים';
$lang['Edit photo information'] = 'שינוי פרטים בתמונה';
$lang['Thumbnail creation'] = 'יצירת תמונה';
$lang['Database synchronization with files'] = 'מסד נתונים לסינכרון עם קבצים';
$lang['all'] = 'כל';
$lang['photos without thumbnail (jpeg and png only)'] = 'תמונות ללא תמונה (JPEG ו-PNG בלבד)';
$lang['height must be a number superior to'] = 'גובה חייב להיות מספר גדול יותר';
$lang['width must be a number superior to'] = 'רוחב חייב להיות מספר גדול יותר';
$lang['for the file format'] = 'עבור פורמט קובץ';
$lang['No missing thumbnail'] = 'אין תמונה חסר';
$lang['Photo unreachable or no support'] = 'תמונה בפורמט נגיש או נתמך';
$lang['GD version'] = 'גרסת ה ';
$lang['Miniaturization parameters'] = 'המזעור הפרמטרים';
$lang['generated in'] = 'נוצר ב';
$lang['Results of miniaturization'] = 'תהליך המזעור תוצאות';
$lang['General statistics'] = 'סטטיסטיקה';
$lang['max time'] = 'זמן מקסימום';
$lang['average time'] = 'הזמן הממוצע';
$lang['min time'] = 'בפעם דקות';
$lang['number of miniaturized photos'] = 'מספר תמונות ממוזערות נוצר';
$lang['total time'] = 'זמן מסך';
$lang['for this file format'] = 'עבור פורמט קובץ זה';
$lang['unit mode'] = 'מצב יחיד';
$lang['Unlocked'] = 'נעולים';
$lang['unset'] = 'Unset';
$lang['Update albums informations'] = 'עדכון פרטים הקטגוריות';
$lang['Update photos information'] = 'עדכון פרטים תמונות';
$lang['Synchronize'] = 'סנכרן';
$lang['reduce to single existing albums'] = 'כדי לצמצם את הקטגוריות הקיימות יחיד';
$lang['Choose an option'] = 'בחר באפשרות';
$lang['display maximum informations (added albums and photos, deleted albums and photos)'] = 'מקסימום מידע לתצוגה (קטגוריות הוסיף אלמנטים, קטגוריות שנמחקו אלמנטים)';
$lang['Piwigo version differs on the remote site'] = 'גרסה שונה Piwigo באתר המרוחק';
$lang['Version of create_listing_file.php on the remote site and Piwigo must be the same'] = 'גרסאות של create_listing_file.php באתר המרוחק Piwigo חייבים להיות זהים';
$lang['listing.xml file was not found'] = 'הקובץ listing.xml לא נמצא';
$lang['listing.xml file was not found on the remote site. This file is generated by choosing the "generate listing" command in the Site manager'] = 'הקובץ listing.xml לא נמצא באתר מרוחק זה הקובץ שנוצר עם ". לייצר רשימה  "הפקודה מנהל האתר';
$lang['Error list'] = 'רשימת שגיאות';
$lang['Errors caption'] = 'שגיאות אגדות';
$lang['Detailed informations'] = 'ידיעות מפורט';
$lang['File/directory read error'] = 'קובץ / ספרייה לקרוא שגיאה';
$lang['The file or directory cannot be accessed (either it does not exist or the access is denied)'] = 'הקובץ או הספרייה לא ניתן לגשת (או שזה לא קיים או הגישה נדחתה)';
$lang['a picture filetype requires a thumbnail. The thumbnail must be present in the sub-directory "thumbnail" of the album directory. The thumbnail filename must start with the configured thumbnail prefix and the extension must be among the following list :'] = 'סוג הקובץ התמונה דורש תמונה תמונה חייב להיות נוכח במדריך קטן ". תמונה  "של המדריך את הקטגוריה תמונה שם הקובץ חייב להתחיל עם הקידומת תמונה מוגדר ההרחבה חייב להיות בין הרשימה הבאה:.';
$lang['missing thumbnail'] = 'חסר תמונה';
$lang['albums deleted in the database'] = 'קטגוריות שנמחקו באתר';
$lang['photos deleted from the database'] = 'אלמנטים שנמחקו באתר';
$lang['photos candidates for metadata synchronization'] = 'תמונות המועמדים לסינכרון מטה';
$lang['photos informations synchronized with files metadata'] = 'אלמנטים ידיעות מסונכרן עם metadata קבצים';
$lang['errors during synchronization'] = 'טעויות במהלך הסנכרון';
$lang['albums added in the database'] = 'הקטגוריות הוסיף באתר';
$lang['photos added in the database'] = 'רכיבים נוספים באתר';
$lang['photos updated in the database'] = 'אלמנטים עודכן באתר';
$lang['Search for new images in the directories'] = 'מחפש תמונות חדשות של ספריות';
$lang['added'] = 'מוסף';
$lang['deleted'] = 'נמחק';
$lang['Metadata synchronization results'] = 'Metadata תוצאות סינכרון';
$lang['only perform a simulation (no change in database will be made)'] = 'רק לבצע סימולציה (דבר יהיה שונה במסד הנתונים)';
$lang['[Simulation]'] = '[הדמיה]';
$lang['Simulation'] = 'הדמיה';
$lang['directories + files'] = 'תמונות + תקיות';
$lang['only directories'] = 'תקיות בלבד';
$lang['synchronize files structure with database'] = 'לסנכרן מבנה קבצים עם מסד נתונים';
$lang['synchronize files metadata with database photos informations'] = 'לסנכרן אלמנטים מסד נתונים עם metadata קבצים';
$lang['even already synchronized photos'] = 'אפילו פריטים שסונכרנו כבר';
$lang['Used metadata'] = 'Metadata בשימוש';
$lang['The name of directories and files must be composed of letters, numbers, "-", "_" or "."'] = 'השם של תיקיות וקבצים חייב לכלול רק אותיות, מספרים, " -  ", " _  "או "  "';
$lang['wrong filename'] = 'שם קובץ שגוי';
$lang['Upload'] = 'העלה';
$lang['user "%s" added'] = 'המשתמש "%s" נוסף';
$lang['User status'] = 'מצב משתמש';
$lang['user_status_admin'] = 'מחובר כמשתמש כמנהל';
$lang['user_status_generic'] = 'מחובר כמשתמש כללי';
$lang['user_status_guest'] = 'מחובר כמשתמש אורח';
$lang['user_status_normal'] = 'מחובר כמשתמש רגיל';
$lang['user_status_webmaster'] = 'מחובר כמשתמש מנהל האתר';
$lang['Virtual album'] = 'הקטגוריה וירטואלית';
$lang['Waiting'] = 'בהמתנה';
$lang['default'] = 'ברירת המחדל';
$lang['Toggle \'default group\' property'] = "תייג 'קבוצת ברירת מחדל' ערך";
$lang['Advanced features'] = 'תכונות מתקדמות';
$lang['Specials'] = 'מבצעים';
$lang['Overall'] = 'מבט';
$lang['Year'] = 'שנה';
$lang['Month'] = 'חודש';
$lang['Day'] = 'יום';
$lang['Pages seen'] = 'דפים שניצפו';
$lang['Time'] = 'זמן';
$lang['IP'] = 'אי פי';
$lang['Element'] = 'מרכיב';
$lang['Section'] = 'סעיף';
$lang['Tags'] = 'תוויות';
$lang['Save page visits by guests'] = 'שמור דפים שניצפו על ידי אורחים';
$lang['Save page visits by users'] = 'שמור דפים שנצפו על ידי משתמשים';
$lang['Save page visits by administrators'] = 'שמור דפים שנצפו על ידי מנהל ראשי';
$lang['An information email was sent to group "%s"'] = 'דואר אלקטרוני נשלח לקבוצה "%s"';
$lang['Send an information email to group members'] = 'שלח הודעת דואר אלקטרוני מידע על חברי הקבוצה';
$lang['Group'] = 'הקבוצה';
$lang['%s value is not correct file because exif are not supported'] = '%s התמונה לא הועלתה כיוון שהאתר לא תומך בפורמט תמונה זה';
$lang['Hello,'] = 'שלום,';
$lang['See you soon.'] = 'נתראה בקרוב.';
$lang['Discover album:'] = 'גלה את הקטגוריה:';
$lang['Mail content'] = 'דואר תוכן';
$lang['none'] = 'אף אחד';
$lang['high'] = 'גבוהה';
$lang['other'] = 'אחרים';
$lang['Element type'] = 'סוג מרכיב';
$lang['Image id'] = 'מזהה תמונה';
$lang['Summary'] = 'סיכום';
$lang['%d line filtered'] = '%d שורה מסומנת';
$lang['%d lines filtered'] = '%d שורות מסומנות';
$lang['%d guest'] = '%d אורח';
$lang['%d guests'] = '%d אורחים';
$lang['Hour'] = 'שעה';
$lang['guest'] = 'האורח';
$lang['default values'] = 'ערכי ברירת המחדל';
$lang['High filesize'] = 'High גודל הקובץ ברזולוציה';
$lang['Guest cannot be deleted'] = 'חוות דעת לא ניתן למחוק';
$lang['Default user cannot be deleted'] = 'המשתמש ברירת מחדל ולא ניתן למחוק';
$lang['Purge history detail'] = 'ההיסטוריה פרטים הטיהור';
$lang['Purge history summary'] = 'ההיסטוריה סיכום הטיהור';
$lang['Check integrity'] = 'בדיקת תקינות';
$lang['Anomaly'] = 'אנומליה';
$lang['Correction'] = 'תיקון';
$lang['Automatic correction'] = 'תיקון אוטומטי';
$lang['Impossible automatic correction'] = 'אוטומטיים impossibl תיקון';
$lang['Correction applied with success'] = 'תיקון מיושם בהצלחה';
$lang['Correction applied with error'] = 'תיקון להחיל עם שגיאה';
$lang['%d anomaly has been detected.'] = '%d חריגה זוהתה.';
$lang['%d anomalies have been detected.'] = '%d חריגות זוהו.';
$lang['%d anomaly has been corrected.'] = '%d חריגה תוקנה.';
$lang['%d anomalies have been detected corrected.'] = '%d חריגות תוקנו.';
$lang['%d anomaly has not been corrected.'] = '%d תריגה לא תוקנה.';
$lang['%d anomalies have not been corrected.'] = '%d חריגות לא תוקנו.';
$lang['[%s] Visit album %s'] = 'עבור אל "%s" או "%s" למידע';
$lang['the forum'] = 'הפורום';
$lang['the wiki'] = 'המילון';
$lang['Go to %s or %s for more informations'] = 'הערך "%s" חייב להיות מדוייק כיוון שלא ניתן להשתמש ב exif';
$lang['%s must be to set to false in your local/config/config.inc.php file'] = '"%s" "חייב להיות מוגדר שווא בקובץ המקומי שלך / / config config.inc.php';
$lang['Main "guest" user does not exist'] = 'המשתמש "אורח" לא קיים';
$lang['Main "guest" user status is incorrect'] = 'הסטטוס של ה"אורח" לא נכון';
$lang['Default user does not exist'] = 'המשתמש של ברירת המחדל אינה קיימת';
$lang['Main "webmaster" user does not exist'] = 'המשתמש "מנהל האתר" לא קיים';
$lang['Main "webmaster" user status is incorrect'] = 'המשתמש "מנהל האתר" לא נכון';
$lang['User "%s" created with "%s" like password'] = 'המשתמש "%s" נוצר עם "%s" ואותה סיסמה';
$lang['Status of user "%s" updated'] = 'הסטטוס של המשתמש "%s" עודכן';
$lang['add new photos to caddie'] = 'הוסף פריט חדש לסל';
$lang['No display'] = 'לא להציג';
$lang['Classic display'] = 'תצוגה קלאסית';
$lang['Hoverbox display'] = 'להציג Hoverbox';
$lang['Mail address is obligatory for all users'] = 'כתובת דואר הוא חובה עבור כל המשתמשים';
$lang['Minimum privacy level'] = 'מינימום רמת הפרטיות';
$lang['Privacy level'] = 'פרטיות ברמה';
$lang['Level 0'] = '---';
$lang['Level 1'] = 'אנשי קשר';
$lang['Level 2'] = 'החברים';
$lang['Level 4'] = 'משפחה';
$lang['Level 8'] = 'מנהלים';
$lang['Reinitialize check integrity'] = 'Reinitialize בדיקת תקינות';
$lang['Check all'] = 'בדוק את כל';
$lang['Uncheck all'] = 'בטל את כל';
$lang['Check automatic corrections'] = 'בדוק תיקונים אוטומטיים';
$lang['Apply selected corrections'] = 'תיקונים שנבחר החל';
$lang['Ignore selected anomalies'] = 'התעלם אנומליות נבחר';
$lang['Refresh'] = 'רענון';
$lang['The anomaly will be ignored until next application version'] = 'האנומליה תתעלם עד לגרסה הבאה הבקשה';
$lang["Correction the anomaly will cancel the fact that it's ignored"] = 'תיקן האנומליה לא יהיה עוד להתעלם ממנו';
$lang['%d anomaly has been ignored.'] = '%d חריגה שהתעלמתה ממנה.';
$lang['%d anomalies have been ignored.'] = '%d חריגות שהתעלמה מהן.';
$lang['Plugins which need upgrade'] = 'תוספים שיש לעדכן';
$lang['Plugin list'] = 'רשימת תוספים';
$lang['Check for updates'] = 'בדוק עדכונים';
$lang['Other plugins'] = 'תוספים נוספים זמינים';
$lang['Last revisions'] = 'התיקונים האחרונים';
$lang['Delete'] = 'מחק';
$lang['Are you sure you want to delete this plugin?'] = 'האם אתה בטוח שאתה רוצה למחוק את התוסף הזה?';
$lang['Are you sure you want to install this plugin?'] = 'האם אתה בטוח שאתה רוצה להתקין את התוסף הזה?';
$lang['Are you sure to install this upgrade? You must verify if this version does not need uninstallation.'] = 'האם אתה בטוח שאתה רוצה להתקין את השדרוג, עליך לוודא אם הגרסה הזאת לא צריך ההסרה לפני?.';
$lang['%s has been successfully upgraded.'] = '"%s" "שודרג בהצלחה.';
$lang['Plugin has been successfully copied'] = 'תוסף הועתקה בהצלחה';
$lang['You might go to plugin list to install and activate it.'] = 'עבור אל רשימת התוספים להתקין ולהפעיל אותו.';
$lang["Can't create temporary file."] = 'קובץ זמני אינו יכול להיווצר.';
$lang["Can't download archive."] = 'ארכיון לא ניתן להוריד.';
$lang["Can't read or extract archive."] = 'ארכיון לא ניתן לקרוא או חילוץ.';
$lang['An error occured during extraction (%s).'] = 'אירעה שגיאה במהלך קבצים ("%s") החילוץ.';
$lang['Please check "plugins" folder and sub-folders permissions (CHMOD).'] = 'בבקשה בדוק את ההרשאות לתיקיה "plugins" ולתת תיקיות שלה (CHMOD)';
$lang["Can't connect to server."] = 'החיבור לשרת בלתי אפשרי.';
$lang['Purge compiled templates'] = 'הידור הטיהור תבניות';
$lang['ACCESS_0'] = 'גישה חופשית';
$lang['ACCESS_1'] = 'גישה לכל';
$lang['ACCESS_2'] = 'גישה למשתמשים רשומים';
$lang['ACCESS_3'] = 'גישה למנהלים';
$lang['ACCESS_4'] = 'גישה למנהל האתר';
$lang['ACCESS_5'] = 'אין גישה';
$lang['Support'] = 'תמיכה';
$lang['Documentation'] = 'תיעוד';
$lang['A new version of Piwigo is available.'] = 'הגרסה החדשה של Piwigo זמין.';
$lang['Piwigo Administration'] = 'המינהל Piwigo';
$lang['Piwigo version'] = 'הגרסה Piwigo';
$lang['You are running the latest version of Piwigo.'] = 'אתה מפעיל את הגירסה העדכנית Piwigo.';
$lang['The version of %s [%s] installed is not compatible with the version required [%s]'] = 'הגרסה של""%s" "["%s"] התקנת אינו תואם לגרסה הנדרש ["%s"]';
$lang['You need to upgrade your system to take full advantage of the application else the application will not work correctly, or not at all'] = 'אתה צריך לשדרג את המערכת שלך כדי לנצל את מלוא היתרונות של הבקשה, אחרת הבקשה יכול לעבוד כראוי, או בכלל לא';
$lang['Deleted on'] = 'נמחק על';
$lang['Last hit'] = 'מכה אחרונה';
$lang['GD library is missing'] = 'ספריית GD חסר';
$lang['Templates'] = 'תבניות';
$lang['Extend for templates'] = 'הרחב תבניות';
$lang['Replacement of original templates by customized templates from template-extension subfolder'] = 'החלפת המקורי תבניות ידי אישית תבניות מ-תיקיית משנה סיומת התבנית';
$lang['Replacers (customized templates)'] = 'ותחליפיו (אישית תבניות)';
$lang['Original templates'] = 'מקורי תבניות';
$lang['Optional URL keyword'] = 'מילת המפתח תכנית אופציונלית';
$lang['Templates configuration has been recorded.'] = 'תצורה תבניות נרשמה.';
$lang['All optimizations have been successfully completed.'] = 'אופטימיזציות כל הושלמו בהצלחה.';
$lang['Optimizations have been completed with some errors.'] = 'אופטימיזציות הושלמו עם שגיאות כמה.';
$lang['Modify information'] = 'שינוי פרטים';
$lang['edit album'] = 'ערוך את מידע הקטגוריה';
$lang['nothing'] = 'שום דבר';
$lang['overrides existing values with empty ones'] = 'מלא ערכים קיימים עם ערכים ריקים';
$lang['manage photo ranks'] = 'נהל את דירוג התמונות';
$lang['Manage photo ranks'] = 'נהל את דירוג התמונות';
$lang['Edit ranks'] = 'ערוך דירוג';
$lang['No photo in this album'] = 'אין פריט בקטגוריה זו';
$lang['Images manual order was saved'] = 'סדר התמונות נשמה';
$lang['ranks'] = 'דירוגים';
$lang['By rank'] = 'לפי דירוג';
$lang['Manual order'] = 'סדר ידני ';
$lang['Drag to re-order'] = 'גרור כדי לסדר מחדש';
$lang['Quick Local Synchronization'] = 'סנכרון מקומי מהיר';
$lang['No photo can be deleted'] = 'לא ניתן למחוק את התמונה';
$lang['Delete selected photos'] = 'מחק רת בתמונות שנבחרו';
$lang['%d photo was deleted'] = '%d תמונה נמחקה';
$lang['%d photos were deleted'] = '%d תמונות נמחקו';
$lang['Downloads'] = 'הורדות';
$lang['Released on'] = 'יצא';
$lang['Number of downloads'] = 'מספר הורדות';
$lang['Piwigo Announcements Newsletter'] = 'עלון Piwigo';
$lang["Keep in touch with Piwigo project, subscribe to Piwigo Announcement Newsletter. You will receive emails when a new release is available (sometimes including a security bug fix, it's important to know and upgrade) and when major events happen to the project. Only a few emails a year."] = 'שמור על קשר עם פרויקט Piwigo, ההירשם לעלון של Piwigo. תישלח אליך הודעות דוא"ל כאשר מהדורה חדשה תיהיה זמינה (לפעמים כולל תיקון באג אבטחה, חשוב לדעת ולשדרג) וכאשר ישנם אירועים מרכזיים הפרויקט. רק כמה הודעות דוא"ל בשנה ';
$lang['Subscribe %s'] = 'הירשם "%s"';
$lang['Subscribe %s to Piwigo Announcements Newsletter'] = 'הרשם""%s" "כדי Piwigo עלון הכרזות';
$lang['Purge search history'] = 'נקה את היסטורית החיפוש';
$lang['Hide'] = 'הסתר';
$lang['Password is missing. Please enter the password.'] = 'סיסמה חסרה, נה להזין סיסמה..';
$lang['Password confirmation is missing. Please confirm the chosen password.'] = 'אישור סיסמה חסר, נה להזיר אישור סיסמה..';
$lang['Password confirmation error.'] = 'שגיאה באישור הסיסמה.';
$lang['Allow users to edit their own comments'] = 'אפשר למשתמשים לערוך הערות משלהם';
$lang['Allow users to delete their own comments'] = 'אפשר למשתמשים למחוק את התגובות שלהם';
$lang['Email administrators when a comment is modified'] = 'שלח מייל למנהלים כאשר תגובה שונתה';
$lang['Email administrators when a comment is deleted'] = 'שלח מייל למנהלים כאשר תגובה נמחקה';
$lang['Cannot delete the old permalink !'] = 'אל תמחק את הPermalink הישן';
$lang['Hit'] = 'לחיצה'; 
$lang['Tools'] = 'כלים';
$lang['Photos'] = 'תמונות';
$lang['Themes'] = 'ערכות נושא';
$lang['Instructions to use Piwigo'] = 'הוראות שימוש Piwigo';
$lang['Installed Themes'] = 'ערכות נושא מותקנות';
$lang['Add New Theme'] = 'הוסף נושא חדש';
$lang['Forbid this theme to users'] = 'לאסור על הנושא הזה למשתמשים';
$lang['Set as default theme for unregistered and new users'] = 'Set as הנושא ברירת המחדל עבור משתמשים רשומים ו החדש';
$lang['unknown'] = 'לא ידוע';
$lang['Upload Photos'] = 'העלאת תמונות';
$lang['Drop into album'] = 'צניחה לתוך הקטגוריה';
$lang['+ Add an upload box'] = '+ הוספת להעלות תיבת ';
$lang['Create the "%s" directory at the root of your Piwigo installation'] = 'יצירת"%s "ספרייה בשורש של ההתקנה שלך Piwigo ';
$lang['Give write access (chmod 777) to "%s" directory at the root of your Piwigo installation'] = 'תן הרשאות (chmod 777) ל"%s" בתקיית שורש איפה שההתקנה שלך נמצאת';
$lang['existing album'] = 'הקטגוריה הקיימת';
$lang['create a new album'] = 'ליצור קטגוריה חדשה ';
$lang['Album name'] = 'שם קטגוריה ';
$lang['Album "%s" has been added'] = 'הקטגוריה "%s" נוספה';
$lang['Uploaded Photos'] = 'התמונות העלאה ';
$lang['%d photos uploaded'] = '%d תמונות הועלו';
$lang['Privacy level set to "%s"'] = 'רמת פרטיות מוגדרת ל "%s"';
$lang['Album "%s" now contains %d photos'] = 'הקטגוריה "%s" מכילה כעט %d תמונות';
$lang['Manage this set of %d photos'] = 'נהל את קבוצת התמונות הזאת (%d תמונות)';
$lang['Select files'] = 'בחר קבצים';
$lang['Everybody'] = 'כולם';
$lang['Who can see these photos?'] = 'מי יכול לראות את התמונות?';
$lang['Who can see this photo?'] = 'מי יכול לראות את התמונה?';
$lang['The websize maximum width must be a number between %d and %d'] = 'רוחב מרבי websize חייב להיות מספר בין% d% d ';
$lang['The websize maximum height must be a number between %d and %d'] = 'הגובה המרבי של האתר חייב להיות מספר בין %d ו %d';
$lang['The websize image quality must be a number between %d and %d'] = 'איכות התמונה באתר חייב להיות מספר בין %d ו %d';
$lang['The thumbnail maximum width must be a number between %d and %d'] = 'הרוחב המרבי של תמונה ממוזערת חייב להיות מספר בין %d ו %d';
$lang['The thumbnail maximum height must be a number between %d and %d'] = 'הגובה המרבי של תמונה ממוזערת חייב להיות מספר בין %d ו %d';
$lang['The thumbnail image quality must be a number between %d and %d'] = 'האיכות המירבית של תמונה ממוזערת חייב להיות מספר בין %d ו %d';
$lang['Settings'] = 'הגדרות';
$lang['Web size photo'] = 'צילום בגודל האתר ';
$lang['Resize'] = 'גודל';
$lang['Maximum Width'] = 'רוחב מרבי';
$lang['pixels'] = 'פיקסלים';
$lang['Maximum Height'] = 'גובה מרבי';
$lang['Image Quality'] = 'איכות תמונה';
$lang['Thumbnail'] = 'תמונה';
$lang['Save Settings'] = 'שמור הגדרות';
$lang['Your configuration settings are saved'] = 'הגדרות התצורה שלך נשמרות ';
$lang['Active Themes'] = 'רקעים פעילים ';
$lang['Add write access to the "%s" directory'] = 'הוסף הרשאת כתיבה לתיקית "%s"';
$lang['Administration Home'] = 'ממשק ניהול';
$lang['Change Admin Colors'] = 'שנה צבעים לתפריט הניהול';
$lang['Delete this theme'] = 'מחק את הנושא הזה';
$lang['Directory does not exist'] = 'הספרייה לא קיימת';
$lang['Download,'] = 'הורדה,';
$lang['FTP + Synchronization'] = 'סנכרון + FTP';
$lang['Get Support on Piwigo Forum'] = 'קבל תמיכה בפורום Piwigo ';
$lang['Help Me'] = 'עזור לי';
$lang['Impossible to activate this theme, the parent theme is missing: %s'] = 'נושא זה לא יכול להיות מופעל, כפי הנושא הורה חסר:"%s" "';
$lang['Impossible to delete this theme. Other themes depends on it: %s'] = 'נושא זה לא ניתן למחוק, כי נושאים אחרים תלוי בו:"%s" "';
$lang['Inactive Themes'] = 'נושאים פעילים';
$lang['Install on your computer,'] = 'להתקין במחשב שלך,';
$lang['Make this theme available to users'] = 'הפוך את הנושא הזה לזמין למשתמשים';
$lang['Page end'] = 'סוף עמוד ';
$lang['Piwigo Uploader'] = 'מעלה Piwigo';
$lang['Operation in progress'] = 'הטיפול עיבוד.';
$lang['Please wait...'] = 'אנא המתן ...';
$lang['Read Piwigo Documentation'] = 'קרא את התיעוד של Piwigo';
$lang['Start pLoader and add your photos.'] = 'התחל להוסיף תמונות שלך.';
$lang['Switch to clear or dark colors for administration'] = 'מעבר צבעים בהיר או כהה עבור ממשק ניהול';
$lang['Theme has been successfully installed'] = 'נושאים הותקן בהצלחה ';
$lang['Visit Gallery'] = 'לבקר בגלריה';
$lang['Visit Piwigo project website'] = 'בקר באתר Piwigo פרוייקט';
$lang['pLoader stands for <em>Piwigo Uploader</em>. From your computer, pLoader prepares your photos and transfer them to your Piwigo photo gallery.'] = 'PLoader יטען <em> Piwigo Uploader </em>. מהמחשב שלך, pLoader יכין את התמונות שלך ןיעביר אותם אל גלרית ה Piwigo שלך';
$lang['Guest Settings'] = 'הגדרות אורחים';
$lang['Main Page'] = 'דף ראשי';
$lang['Photo Page'] = 'מקור תמונה';
$lang['Activate Navigation Bar'] = 'להפעיל את סרגל הניווט';
$lang['Activate Navigation Thumbnails'] = 'הפעל ממוזערות ניווט';
$lang['Activate icon "%s"'] = 'להפעיל את סמל"%s "';
$lang['Activate field "%s"'] = 'להפעיל את השדה"%s"';
$lang['Photo Properties'] = 'מאפייני תמונה';
$lang['Allow user customization'] = 'לאפשר התאמה אישית למשתמש';
$lang['Languages'] = 'שפות';
$lang['Installed Languages'] = 'מהשפות המותקנות';
$lang['Add New Language'] = 'הוספת שפה חדשה';
$lang['Language has been successfully installed'] = 'שפה הותקן בהצלחה';
$lang['Select:'] = 'בחר:';
$lang['None'] = 'אף אחד';
$lang['Invert'] = 'מרחב';
$lang['Impossible to deactivate this theme, you need at least one theme.'] = 'אי אפשר לנטרל את הנושא הזה, אתה צריך לפחות נושא אחד.';
$lang['Webmaster status is required.'] = 'מצב Webmaster נדרשת.';
$lang['Bound Theme'] = 'נושאים Bound';
$lang['Allow rating'] = 'אפשר דירוג';
$lang['Select at least one comment'] = 'בחר אחת לפחות להגיב';
$lang['Active Plugins'] = 'תוספים פעילים';
$lang['Inactive Plugins'] = 'תוספים פעילים';
$lang['Missing Plugins'] = 'תוספים חסרים';
$lang['Uninstalled Plugins'] = 'תוספים הוסר';
$lang['By %s'] = 'הועלה ע"י "%s"';
$lang['Visit plugin site'] = 'בקר תוסף האתר';
$lang['Active Languages'] = 'שפות פעילים';
$lang['Delete this language'] = 'מחק את השפה הזאת';
$lang['Forbid this language to users'] = 'לאסור על השפה הזו למשתמשים';
$lang['Impossible to deactivate this language, first set another language as default.'] = 'אי אפשר לבטל את השפה הזו, הראשון להגדיר שפה אחרת כברירת המחדל.';
$lang['Impossible to deactivate this language, you need at least one language.'] = 'אי אפשר לבטל את השפה הזאת, אתה צריך לפחות שפה אחת.';
$lang['Inactive Languages'] = 'שפות לא פעילה';
$lang['Make this language available to users'] = 'הפוך את השפה הזו זמינה למשתמשים';
$lang['Set as default language for unregistered and new users'] = 'הפוך שפת ברירת מחדל עבור משתמשים רשומים ו החדש';
$lang['Add Photos'] = 'הוספת תמונות';
$lang['Download'] = 'הורד';
$lang['The following tag was deleted'] = 'התווית הבאה נמחקה';
$lang['Miscellaneous'] = 'שונות';
$lang['Virtual Links'] = 'קישורים וירטואלית';
$lang['There is no other language available.'] = 'אין שפה אחרת זמינה.';
$lang['There is no other plugin available.'] = 'אין שום תוספים אחרים זמינים.';
$lang['There is no other theme available.'] = 'אין שום נושא אחר זמין.';
$lang['Add another set of photos'] = 'הוספת קבוצה נוספת של אוהדים';
$lang['Order of menubar items has been updated successfully.'] = 'סדר הפריטים Menubar עודכנו בהצלחה.';
$lang['This theme was not designed to be directly activated'] = 'הנושא הזה לא נועד להיות מופעל באופן ישיר';
$lang['Pending Comments'] = 'תגובות בהמתנה';
$lang['In your php.ini file, the upload_max_filesize (%sB) is bigger than post_max_size (%sB), you should change this setting'] = 'בקובץ php.ini שלך, upload_max_filesize (SB%) הוא גדול יותר post_max_size (SB%), עליך לשנות הגדרה זו';
$lang['Exif extension not available, admin should disable exif use'] = 'סיומת Exif לא נתמכת, פנה למנהל על מנת שיאשר שימוש בסיומת Exif';
$lang['The uploaded file exceeds the upload_max_filesize directive in php.ini: %sB'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini: "%s "B';
$lang['The uploaded files exceed the post_max_size directive in php.ini: %sB'] = 'The uploaded files exceed the post_max_size directive in php.ini: "%s "B';
$lang['The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form'] = 'הקובץ שבועלה חורג מה MAX_FILE_SIZE האפשרי שצויין בקובץ html';
$lang['The uploaded file was only partially uploaded'] = 'הקובץ הועלה חלקית';
$lang['No file was uploaded'] = 'לא הועלה קובץ';
$lang['Missing a temporary folder'] = 'חסר תיקיה זמנית';
$lang['Failed to write file to disk'] = 'נכשל בכתיבת הקובץ בדיסק';
$lang['File upload stopped by extension'] = 'העלאת קובץ נכשלה ובמשתמע';
$lang['Unknown upload error'] = 'שגיאה בהעלאה לא ידועה';
$lang['Error on file "%s" : %s'] = 'שגיאה בקובץ "%s" : %s';
$lang['Menu Management'] = 'נהל תפריטים';
$lang['automatic order'] = 'סדר אוטומטי';
$lang['manual order'] = 'סדר ידני';
$lang['Albums automatically sorted'] = 'מיון אלבומים אוטומטי';
$lang['Keep high definition'] = 'שמור על חדות גבוהה';
$lang['The high definition maximum width must be a number between %d and %d'] = 'הגדרת הרוחב המקסימלי חייב להיות מספר בין %d ו %d';
$lang['The high definition maximum height must be a number between %d and %d'] = 'הגדרת הגובהה המקסימלי חייב להיות מספר בין %d ו %d';
$lang['The high definition image quality must be a number between %d and %d'] = 'הגדרת האיכות הטובה ביותר חייבת להיות מספר בין %d ו %d';
$lang['Batch Manager'] = 'מנהל קבוצה';
$lang['include child albums'] = 'כולל אלבום ילד';
$lang['Selection'] = 'מבחר';
$lang['Action'] = 'פעולה';
$lang['Set author'] = 'הגדר מחבר';
$lang['Set title'] = 'הגדר כותרת';
$lang['Set creation date'] = 'הגדר תאריך יצירה';
$lang['Apply action'] = 'החל';
$lang['on the %d selected photos'] = 'ב %d תמונות נבחרות';
$lang['%d of %d photos selected'] = '%d מ %d תמונות נבחרו';
$lang['No photo selected, %d photos in current set'] = 'לא נבחרו תמונות, %d תמונות בסט הנוכחי';
$lang['All %d photos are selected'] = 'כל %d התמונות נבחרו';
$lang['remove this filter'] = 'הסר מסנן זה';
$lang['predefined filter'] = 'סנן מראש';
$lang['last import'] = 'הגיעה לאחרונה';
$lang['with no virtual album'] = 'ללא אלבום וירטואלי';
$lang['duplicates'] = 'כפילויות';
$lang['Add a filter'] = 'הוסף מסנן';
$lang['Remove all filters'] = 'מחק את כל המסננים';
$lang['Refresh photo set'] = 'רענן את סט התמונות';
$lang['The whole page'] = 'העמוד המלא';
$lang['The whole set'] = 'הסט המלא';
$lang['No photo in the current set.'] = 'אין תמונות בסט הנוכחי.';
$lang['No photo selected, no action possible.'] = 'לא נבחרו תמונות, אין פעולות אפשריות.';
$lang['Choose an action'] = 'בחר פעולה';
$lang['remove author'] = 'הסר מחבר';
$lang['Type here the author name'] = 'כתוב כאן את שם המחבר';
$lang['remove title'] = 'הסר כותרת';
$lang['Type here the title'] = 'כתוב כאן את הכותרת';
$lang['remove creation date'] = 'הסר את תאריך היצירה';
$lang['with no album'] = 'ללא אלבום';
$lang['with no tag'] = 'ללא תיוג';
$lang['Album photos associated to the following albums: %s'] = 'אלבום תמונות משוייך לאלבום הבא: %s';
$lang['Delete orphan tags'] = 'מחק תגים יתומים';
$lang['delete photo'] = 'מחק תמונה';
$lang['new'] = 'חדש';
$lang['No results'] = 'אין תוצאות';
$lang['Orphan tags deleted'] = 'תגים יתומים נמחקו';
$lang['Remove from caddie'] = 'הוסר מהנושא';
$lang['Searching...'] = 'מחפש...';
$lang['Type in a search term'] = 'הקלד את ערך החיפוש';
$lang['Week starts on'] = 'שבוע מתחיל';
$lang['You have %d orphan tags: %s.'] = 'יש לך %d תגים יתומים: %s.';
$lang['Themes which need upgrade'] = 'ערכות נושא שצריכות שידרוג';
$lang['Languages which need upgrade'] = 'שפות שצריכות שידרוג';
$lang['All themes are up to date.'] = 'כל ערכות הנושא מעודכנות';
$lang['All plugins are up to date.'] = 'כל התוספים מעודכנים.';
$lang['All languages are up to date.'] = 'כל השפות מעודכנות.';
$lang['Visit theme site'] = 'בקר באתר ערכת הנושא';
$lang['Visit language site'] = 'בקר באתר השפה';
$lang['New Version'] = 'גרסה חדשה';
$lang['Obsolete Plugins'] = 'תוסף מיושן';
$lang['WARNING! This plugin does not seem to be compatible with this version of Piwigo.'] = 'אזהרה! נראה כי תוסף זה לא מתאים ל Piwigo.';
$lang['Do you want to activate anyway?'] = 'אתה רוצה להפעיל בכל מיקרה?';
$lang['THIS PLUGIN IS NOW PART OF PIWIGO CORE! DELETE IT NOW.'] = 'תוסף זה הוא לא חלק מליבת PIWIGO ! הסר אותו מייד!';
$lang['ERROR: THIS PLUGIN IS MISSING BUT IT IS INSTALLED! UNINSTALL IT NOW.'] = 'שגיאה: תוסף זה נראה חסר אבל מותקן! הסר אותו מייד.';
$lang['display'] = 'הצג';
$lang['You can update to Piwigo %s directly, without upgrading to Piwigo %s (recommended).'] = 'אתה יכול לעדכן ל Piwigo %s ישירות, מבלי לשדרג ל Piwigo %s (מומלץ).';
$lang['Save Template Directory'] = 'שמור בספרייה תבנית';
$lang['Dump Database'] = 'זרוק מסד נתונים';
$lang['Include history data (Warning: server memory limit may be exceeded)'] = 'כלול נתוני היסטוריה אזהרה:עלולה להיות חריגת זיכרון השרת';
$lang['Unable to write new local directory.'] = 'אין אפשרות לכתוב ספריה מקומית חדשה.';
$lang['Unable to send template directory.'] = 'אין אפשרות לשלוח ספריית תבנית.';
$lang['Unable to dump database.'] = 'אין אפשרות לזרות מסד נתונים.';
$lang['Some upgrades are available for extensions.'] = 'כמה שידרוגים זמינים להרחבות.';
$lang['Ignore All'] = 'התעלם מהכל';
$lang['Crop'] = 'להניב';
$lang['Width'] = 'רוחב';
$lang['Height'] = 'גובה';
$lang['Follow Orientation'] = 'עקוב אחר ההדרכה';
$lang['If you want to regenerate thumbnails, please go to the <a href="%s">Batch Manager</a>.'] = 'אם ברצונך לחדש את התמונות הממוזערות נווט בבקשה ל <a href="%s">מנהל אצווה</a>.';
$lang['Graphics Library'] = 'ספריית גרפיקה';
$lang['Activate icon "new" next to albums and pictures'] = 'הפעל כפתו "חדש" ליד אלבומים';
$lang['Deactivate all'] = 'בטל פעולה להכל';
$lang['Default photos order'] = 'סדר ברירת מחדל לתמונות';
$lang['Restore'] = 'שחזר';
$lang['Restore default configuration. You will lose your plugin settings!'] = 'שחזר להגדרות ברירת מחדל. הגדרות ההתקן יאבדו!';
$lang['Show menubar'] = 'הצג תפריט';
$lang['Regenerate Thumbnails'] = 'חידוש תמונות ממוזערות';
$lang['Regenerate Websize Photos'] = 'חידוש גודל תמונות באתר';
$lang['Thumbnails generation in progress...'] = 'חידוש תמונות ממוזערות בתהליך...';
$lang['Photos generation in progress...'] = 'חידוש תמונות בתהליך...';
$lang['%s thumbnails have been regenerated'] = '%s תמונות ממוזערות חודשו';
$lang['%s thumbnails can not be regenerated'] = '%s תמונות ממוזערות לא יכלו להתחדש';
$lang['%s photos have been regenerated'] = '%s תמונות חודשו';
$lang['%s photos can not be regenerated'] = '%s תמונות לא יכלו להתחדש';
$lang['Updates'] = 'עדכונים';
$lang['Update in progress... Please wait.'] = 'עדכון בתהליך... המתן.';
$lang['Ignore this update'] = 'התעלם מעידכון זה';
$lang['Reset ignored updates'] = 'אפס התעלמות מעידכונים';
$lang['Update All'] = 'עדכן הכל';
$lang['ERROR'] = 'שגיאה';
$lang['Update Complete'] = 'עידכון הושלם';
$lang['Piwigo Update'] = 'Piwigo עדכון';
$lang['Extensions Update'] = 'עדכון הרחבה';
$lang['All extensions are up to date.'] = 'כל ההרחבות מעודכנות.';
$lang['Following plugins may not be compatible with the new version of Piwigo:'] = 'יכול להיות שההתקן לא תואם לגירסה החדשה של Piwigo:';
$lang['Following themes may not be compatible with the new version of Piwigo:'] = 'יכול להיות שהערכת הנושא לא תואמת לגירסה החדשה של Piwigo:';
$lang['I decide to update anyway'] = 'החלתי לעדכן בכל מיקרה';
$lang['Update to Piwigo %s'] = 'עדכן ל Piwigo %s';
$lang['Two updates are available'] = 'שני עידכונים זמינים';
$lang['This is a minor update, with only bug corrections.'] = 'זהו עידכון שולי, תיקון באגים שנמצאו.';
$lang['This is a major update, with <a href="%s">new exciting features</a>.'] = 'עדכון חשוב, עם <a href="%s">מאפיינים חדשים ומלהיבים</a>.';
$lang['Some themes and plugins may be not available yet.'] = 'יכול להיות שחלק מההתקנים וערכות הנושא לא זמינים עדיין .';
$lang['Learn more'] = 'למד עוד';
$lang['Rate'] = "דרג";
$lang['Average rate'] = "דירוג ממוצע";
$lang['(this tag will be deleted)'] = ')התג הזה ימחק(';
$lang['... or '] = 'או ...';
$lang['Add a criteria'] = 'הוסף קריטריון';
$lang['Allowed file types: %s.'] = 'סוגי קבצים מותרים:%s';
$lang['Approximate maximum resolution: %dM pixels (that\'s %dx%d pixels).'] = 'רזולוציה מקסימלית: %dM פקסלים(שזה %dx%d פקסלים).';
$lang['By default, Piwigo will create a new websize from the HD (high definition) version of your photo.'] = 'כברירת מחדל, Piwigo יצור גודל חדש לתמונות ה HD שלך.';
$lang['Confirm merge'] = 'אשר איחוד';
$lang['Create'] = 'צור';
$lang['hide details'] = 'הסתר פרטים';
$lang['Manage Permissions'] = 'ניהול הרשאות';
$lang['Maximum file size: %sB.'] = 'גודל קובץ מקסימאלי: %sB.';
$lang['Merge selected tags'] = 'אחד תגים מסומנים';
$lang['Merge tags'] = 'איחוד תגים';
$lang['No destination tag selected'] = 'לא ניבחרו תגי יעד';
$lang['Photo %s of %s'] = 'תמונה %s מ %s';
$lang['Select an album'] = 'בחר אלבום';
$lang['Select at least two tags for merging'] = 'בחר לפחות שני תגים לאיחוד';
$lang['Select the destination tag'] = 'בחר תגים ביעד';
$lang['show details'] = 'הצג פרטים';
$lang['Start Upload'] = 'התחל העלאה';
$lang['Tags <em>%s</em> merged into tag <em>%s</em>'] = 'התג <em>%s</em> אוחד כעם תג <em>%s</em>';
$lang['You are using the Browser uploader. Try the <a href="%s">Flash uploader</a> instead.'] = 'אתה משתמש בהעלאה מהדפדפן. נסה <a href="%s">העלאת פלאש</a> במקום.';
$lang['You are using the Flash uploader. Problems? Try the <a href="%s">Browser uploader</a> instead.'] = 'אתה משתמש בהעלאת פלאש. ישנה בעיה? נסה <a href="%s">העלאה מהדפדפן</a> במקום.';
$lang['You can\'t define a default photo order because you have a custom setting in your local configuration.'] = 'אין באפשרותך לקבוע סדר תמונות ברירת מחדל מכיוון שאתה משתמש בהגדרות מותאמות אישית';
?>